@@ -20,6 +20,11 @@ class InteligerManager(models.Manager):
     def get_queryset(self):
         return InteligerQuerySet(self.model)
 
+    def ativos(self):
+        return self.get_queryset().ativos()
+
+    def desabilitar(self):
+        return self.get_queryset().desabilitar()
 
 class DatLog(models.Model):
     dat_insercao = models.DateTimeField(auto_now_add=True, null=True)
